# TODO: If the homology package ever reappears online, this package wants it.
# TODO: If the Singular package gets a usable license, this package wants it.

%global pkgname hap

Name:           gap-pkg-%{pkgname}
Version:        1.11
Release:        2%{?dist}
Summary:        Homological Algebra Programming for GAP

License:        GPLv2+
URL:            http://hamilton.nuigalway.ie/Hap/www/
Source0:        http://hamilton.nuigalway.ie/Hap/%{pkgname}%{version}.tar.gz
# Fix documentation bugs
Patch0:         %{name}-doc.patch
BuildArch:      noarch

BuildRequires:  gap-devel
BuildRequires:  GAPDoc-latex
BuildRequires:  gap-pkg-aclib
BuildRequires:  gap-pkg-congruence
BuildRequires:  gap-pkg-crystcat
BuildRequires:  gap-pkg-edim
BuildRequires:  gap-pkg-nq
BuildRequires:  gap-pkg-polycyclic
BuildRequires:  gap-pkg-polymaking
BuildRequires:  gcc
BuildRequires:  graphviz
BuildRequires:  ImageMagick
BuildRequires:  perl
BuildRequires:  vim-minimal
BuildRequires:  xdg-utils

Requires:       coreutils
Requires:       gap-core
Requires:       gap-pkg-crystcat
Requires:       gap-pkg-polycyclic
Requires:       xdg-utils

Recommends:     gap-pkg-aclib
Recommends:     gap-pkg-congruence
Recommends:     gap-pkg-edim
Recommends:     gap-pkg-nq
Recommends:     gap-pkg-polymaking

Suggests:       asymptote
Suggests:       graphviz
Suggests:       ImageMagick
Suggests:       openssh-clients

%description
HAP is a homological algebra library for use with the GAP computer
algebra system, and is still under development.  Its initial focus is on
computations related to the cohomology of groups.  Both finite and
infinite groups are handled, with emphasis on integral coefficients.

Recent additions include some functions for computing homology of
crossed modules and simplicial groups, and also some functions for
handling simplicial complexes, cubical complexes and regular
CW-complexes in the context of topological data analysis.

%prep
%setup -q -n Hap%{version}
%patch0

fixtimestamp() {
  touch -r $1.orig $1
  rm -f $1.orig
}

# Change the path to the perl executable
for fil in lib/PolyComplexes/{oldprog,prog,progold}; do
  sed -i.orig 's,/usr/local/bin/perl,%{_bindir}/perl,' $fil
  fixtimestamp $fil
done

# Don't force the web browser to be firefox
sed -i.orig 's/"firefox"/"xdg-open"/' lib/externalSoftware.gap
fixtimestamp lib/externalSoftware.gap

# Replace glacially slow vi scripts with speedy sed scripts
cat << EOF > lib/TitlePage/vis
#!/bin/sh
if [ $# -gt 0 ]; then
  sed -e 's,<Item>,<Br/>,g' \\
      -e 's,<Row>,<Br/>,g' \\
      -e 's,</Item>,<Br/>,g' \\
      -e 's,</Row>,<Br/>,g' \\
      -e 's,<Table Align="|l|" >,<Br/>,g' \\
      -e 's,</Table>,<Br/>,g' \\
      -e 's,<List>,<Br/>,g' \\
      -e 's,</List>,<Br/>,g' \\
      -e 's,</C>,&<Br/>,g' \\
      -e 's,</Index>,&::::::::::::::::::::::::<Br/>,g' \\
      -i $@
fi
EOF
cat << EOF > lib/TitlePage/viscript
#!/bin/sh
if [ $# -gt 0 ]; then
  sed -e 's,<h3>Contents</h3>,<h2>HAP Functions</h2>,g' \
      -e 's,<p><code,<code,g' \
      -e 's,code></p>,code>,g' \
      -e '16d' \
      -e 's,<body>,&<a href="../www/index.html"><small>HAP home</small></a>,' \
      -e 's,<table,& cellspacing="10",' \
      -i $@
fi
EOF

# Remove obsolete files
find . -name \*working\* | xargs rm -f
rm -fr doc/*.old lib/*/*old* www/SideLinks/About/*OLD*

# Clean up documentation to force complete rebuild
rm -fr pdfdoc/*
rm -f doc/*.{aux,bbl,blg,dvi,html,idx,ilg,ind,log,out,pdf,pnr,six,tex,toc,txt}

# Update obsolete documentation constructs
for fil in doc/*.xml doc/newman/*.xml; do
  sed -i.orig 's/|l|/|p{\\textwidth}|/;s,<Verb>\(.*\)</Verb>,<C>\1</C>,' $fil
  fixtimestamp $fil
done

# Fix a small typo
sed -i.orig 's/^\tbreak/\t#break/' lib/RahmSanchez/DavisComplex.gi
fixtimestamp lib/RahmSanchez/DavisComplex.gi

# Fix end of line encoding
sed -i.orig 's/\r//' doc/manual.css
fixtimestamp doc/manual.css

# Nearly every file has the executable bit on.  Turn them all off, then restore
# the handful where that is actually correct.
find -O3 . -type f -perm /0111 | xargs chmod a-x
chmod a+x compile* uncompile* doc/newman/{llaregub,xmltex} \
      lib/PolyComplexes/prog lib/TitlePage/vis*

%build
# Build the documentation
export LC_ALL=en_US.UTF-8
mkdir ../pkg
ln -s ../Hap%{version} ../pkg
# TODO: If we ever get Singular support working, also call MakeHAPprimeDoc().
gap -l "$PWD/..;%{_gap_dir}" << EOF
LoadPackage( "Hap" );
MakeHAPManual();
EOF
rm -fr ../pkg

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../Hap%{version} %{buildroot}%{_gap_dir}/pkg/Hap
chmod a-x %{buildroot}%{_gap_dir}/pkg/Hap/doc/newman/{llaregub,xmltex}
rm -f %{buildroot}%{_gap_dir}/pkg/Hap/{compile*,README.HAP,uncompile*}
rm -f %{buildroot}%{_gap_dir}/pkg/Hap/doc/{.idl.ilg,.idl.ind,.ind}
rm -fr %{buildroot}%{_gap_dir}/pkg/Hap/lib/CompiledGAP
find %{buildroot}%{_gap_dir}/pkg/Hap -name .\*swp -exec rm {} +

%check
# Expect "unbound global variable" warnings because we have neither the GAP
# singular package nor the GAP homology package in Fedora.
export LC_ALL=en_US.UTF-8
cd test
gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" test.gap 2>&1 | tee log
grep -Fvq 'There are some problems' log
rm -f log

%files
%doc README.HAP
%license www/copyright/*.html
%docdir %{_gap_dir}/pkg/Hap/doc
%docdir %{_gap_dir}/pkg/Hap/pdfdoc
%{_gap_dir}/pkg/Hap/

%changelog
* Tue Aug 16 2016 Jerry James <loganjerry@gmail.com> - 1.11-2
- Switch crystcat from Recommends to Requires

* Fri Aug  5 2016 Jerry James <loganjerry@gmail.com> - 1.11-1
- Initial RPM
